@@ -29,8 +29,6 @@ GType anjuta_property_object_type_get_type (void) G_GNUC_CONST;
 #define ANJUTA_TYPE_PROPERTY_OBJECT_TYPE (anjuta_property_object_type_get_type())
 GType anjuta_property_data_type_get_type (void) G_GNUC_CONST;
 #define ANJUTA_TYPE_PROPERTY_DATA_TYPE (anjuta_property_data_type_get_type())
-GType anjuta_preferences_filter_type_get_type (void) G_GNUC_CONST;
-#define ANJUTA_TYPE_PREFERENCES_FILTER_TYPE (anjuta_preferences_filter_type_get_type())
 /* enumerations from "anjuta-launcher.h" */
 GType anjuta_launcher_output_type_get_type (void) G_GNUC_CONST;
 #define ANJUTA_TYPE_LAUNCHER_OUTPUT_TYPE (anjuta_launcher_output_type_get_type())
@@ -43,6 +41,9 @@ GType anjuta_serializer_mode_get_type (void) G_GNUC_CONST;
 /* enumerations from "anjuta-vcs-status.h" */
 GType anjuta_vcs_status_get_type (void) G_GNUC_CONST;
 #define ANJUTA_TYPE_VCS_STATUS (anjuta_vcs_status_get_type())
+/* enumerations from "gbf-project.h" */
+GType if_if_get_type (void) G_GNUC_CONST;
+#define ANJUTA_TYPE_IF (if_if_get_type())
 G_END_DECLS
 
 #endif /* __ANJUTA_ENUM_TYPES_H__ */
