@@ -15,8 +15,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.  
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.  
  */
 
 /**
@@ -214,7 +214,7 @@ static guint plugin_signals[LAST_SIGNAL] = { 0 };
 static void anjuta_plugin_finalize (GObject *object);
 static void anjuta_plugin_class_init (AnjutaPluginClass *class);
 
-GNOME_CLASS_BOILERPLATE (AnjutaPlugin, anjuta_plugin, GObject, G_TYPE_OBJECT);
+G_DEFINE_TYPE (AnjutaPlugin, anjuta_plugin, G_TYPE_OBJECT);
 
 static void
 destroy_watch (Watch *watch)
@@ -310,7 +310,7 @@ static void
 anjuta_plugin_class_init (AnjutaPluginClass *class) 
 {
 	GObjectClass *object_class = (GObjectClass*) class;
-	parent_class = g_type_class_peek_parent (class);
+	GObjectClass *parent_class = g_type_class_peek_parent (class);
     
 	object_class->dispose = anjuta_plugin_dispose;
 	object_class->finalize = anjuta_plugin_finalize;
@@ -350,7 +350,7 @@ anjuta_plugin_class_init (AnjutaPluginClass *class)
 }
 
 static void
-anjuta_plugin_instance_init (AnjutaPlugin *plugin)
+anjuta_plugin_init (AnjutaPlugin *plugin)
 {
 	plugin->priv = g_new0 (AnjutaPluginPrivate, 1);
 }
@@ -538,13 +538,8 @@ anjuta_plugin_activate (AnjutaPlugin *plugin)
 	plugin->priv->activated = klass->activate(plugin);
 	
 	if (plugin->priv->activated)
-	{
-		if (IANJUTA_IS_PREFERENCES(plugin))
-			ianjuta_preferences_merge(IANJUTA_PREFERENCES(plugin),
-				ANJUTA_PREFERENCES(anjuta_shell_get_preferences(plugin->shell,
-																NULL)), NULL);
 		g_signal_emit_by_name (G_OBJECT (plugin), "activated");
-	}
+
 	return plugin->priv->activated;
 }
 
@@ -571,10 +566,6 @@ anjuta_plugin_deactivate (AnjutaPlugin *plugin)
 	klass = ANJUTA_PLUGIN_GET_CLASS(plugin);
 	g_return_val_if_fail (klass->deactivate != NULL, FALSE);
 	
-	if (IANJUTA_IS_PREFERENCES(plugin))
-		ianjuta_preferences_unmerge(IANJUTA_PREFERENCES(plugin),
-			ANJUTA_PREFERENCES(anjuta_shell_get_preferences(plugin->shell, NULL)), NULL);
-	
 	success = klass->deactivate(plugin);
 	plugin->priv->activated = !success;
 	if (!plugin->priv->activated)
