@@ -44,7 +44,6 @@ get_program_parameters (BasicAutotoolsPlugin *plugin,
 						gchar **program_args,
 						gboolean *run_in_terminal)
 {
-	GError* error = NULL;
 	GtkBuilder *bxml;
 	GtkWidget *dlg, *treeview, *use_terminal_check, *arguments_entry;
 	GtkWidget *treeview_frame;
@@ -79,17 +78,16 @@ get_program_parameters (BasicAutotoolsPlugin *plugin,
 		exec_targets = NULL;
 	}
 
-	bxml = gtk_builder_new();
-	if (!gtk_builder_add_from_file (bxml, BUILDER_FILE, &error))
-	{
-		g_warning ("Couldn't load builder file: %s", error->message);
-		g_error_free (error);
-	}		
-	dlg = GTK_WIDGET (gtk_builder_get_object (bxml, "execute_dialog"));
-	treeview = GTK_WIDGET (gtk_builder_get_object (bxml, "programs_treeview"));
-	treeview_frame = GTK_WIDGET (gtk_builder_get_object (bxml, "treeview_frame"));
-	use_terminal_check = GTK_WIDGET (gtk_builder_get_object (bxml, "program_run_in_terminal"));
-	arguments_entry = GTK_WIDGET (gtk_builder_get_object (bxml, "program_arguments"));
+	bxml = anjuta_util_builder_new (BUILDER_FILE, NULL);
+	if (bxml == NULL) return FALSE;
+	anjuta_util_builder_get_objects (bxml,
+	    "execute_dialog", &dlg,
+	    "programs_treeview", &treeview,
+	    "treeview_frame", &treeview_frame,
+	    "program_run_in_terminal", &use_terminal_check,
+	    "program_arguments", &arguments_entry,
+	    NULL);
+	g_object_unref (bxml);
 	
 	gtk_window_set_transient_for (GTK_WINDOW (dlg),
 								  GTK_WINDOW (ANJUTA_PLUGIN(plugin)->shell));
@@ -214,7 +212,7 @@ get_program_parameters (BasicAutotoolsPlugin *plugin,
 		}
 	}
 	gtk_widget_destroy (dlg);
-	g_object_unref (bxml);
+	
 	return success;
 }
 
@@ -406,20 +404,20 @@ execute_program (BasicAutotoolsPlugin* plugin, const gchar *pre_select_uri)
 
 				g_free (oldcmd);
 			} else {
-				gchar* launcher_path = g_find_program_in_path("anjuta_launcher");
+				gchar* launcher_path = g_find_program_in_path("anjuta-launcher");
 
 				if (launcher_path != NULL)
 				{
 					gchar* oldcmd = cmd;
 				
-					cmd = g_strconcat ("anjuta_launcher ", oldcmd, NULL);
+					cmd = g_strconcat ("anjuta-launcher ", oldcmd, NULL);
 
 					g_free (oldcmd);
 					g_free (launcher_path);
 				}
 				else
 				{
-					DEBUG_PRINT("%s", "Missing anjuta_launcher");
+					DEBUG_PRINT("%s", "Missing anjuta-launcher");
 				}
 				
 			}
