@@ -26,8 +26,7 @@
 #define _FILE_MODEL_H_
 
 #include <glib-object.h>
-#include <gtk/gtktreestore.h>
-#include <gtk/gtktreeview.h>
+#include <gtk/gtk.h>
 #include <gio/gio.h>
 
 G_BEGIN_DECLS
@@ -49,9 +48,11 @@ enum
 	COLUMN_PIXBUF,
 	COLUMN_FILENAME,
 	COLUMN_DISPLAY,
+	COLUMN_STATUS,
 	COLUMN_FILE,
 	COLUMN_IS_DIR,
 	COLUMN_SORT,
+	COLUMN_DUMMY,
 	N_COLUMNS
 };
 
