@@ -15,14 +15,15 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
 #include <libanjuta/anjuta-plugin.h>
 #include <libanjuta/interfaces/ianjuta-editor.h>
 #include <libanjuta/interfaces/ianjuta-symbol-manager.h>
+#include "cpp-java-assist.h"
 
-extern GType cpp_java_plugin_get_type (AnjutaGluePlugin *plugin);
+extern GType cpp_java_plugin_get_type (GTypeModule *module);
 #define ANJUTA_TYPE_PLUGIN_CPP_JAVA         (cpp_java_plugin_get_type (NULL))
 #define ANJUTA_PLUGIN_CPP_JAVA(o)           (G_TYPE_CHECK_INSTANCE_CAST ((o), ANJUTA_TYPE_PLUGIN_CPP_JAVA, CppJavaPlugin))
 #define ANJUTA_PLUGIN_CPP_JAVA_CLASS(k)     (G_TYPE_CHECK_CLASS_CAST ((k), ANJUTA_TYPE_PLUGIN_CPP_JAVA, CppJavaPluginClass))
@@ -52,10 +53,10 @@ struct _CppJavaPlugin {
 	gint param_brace_indentation;
 	gint param_case_indentation;
 	gint param_label_indentation;
+	gboolean smart_indentation;
 	
 	/* Assist */
-	GList* suggestions;
-	IAnjutaSymbolManager* symbol_browser;
+	CppJavaAssist *assist;
 };
 
 struct _CppJavaPluginClass {
