@@ -18,7 +18,10 @@
 #ifndef MESSAGE_VIEW_H
 #define MESSAGE_VIEW_H
 
-#include <gnome.h>
+#include <glib/gi18n.h>
+#include <gtk/gtk.h>
+#include <gdk/gdk.h>
+#include <gdk/gdkkeysyms.h>
 #include <libanjuta/anjuta-preferences.h>
 #include <libanjuta/anjuta-serializer.h>
 
@@ -58,11 +61,12 @@ struct _MessageViewClass
 
 /* Note: MessageView implements IAnjutaMessageView interface */
 GType message_view_get_type (void);
-GtkWidget* message_view_new (AnjutaPreferences* prefs, GtkWidget* popup_menu);
+GtkWidget* message_view_new (GtkWidget* popup_menu);
 
 void message_view_next(MessageView* view);
 void message_view_previous(MessageView* view);
 void message_view_save(MessageView* view);
+void message_view_copy(MessageView* view);
 gboolean message_view_serialize (MessageView *view,
 								 AnjutaSerializer *serializer);
 gboolean message_view_deserialize (MessageView *view,
