@@ -5,9 +5,9 @@
  * Copyright (C) [+Author+] [+(shell "date +%Y")+] <[+Email+]>
  * 
 [+CASE (get "License") +]
-[+ == "BSD"  +][+(bsd  "main.cc" (get "Author") " * ")+]
-[+ == "LGPL" +][+(lgpl "main.cc" (get "Author") " * ")+]
-[+ == "GPL"  +][+(gpl  "main.cc"                " * ")+]
+[+ == "BSD"  +][+(bsd  (get "Name") (get "Author") " * ")+]
+[+ == "LGPL" +][+(lgpl (get "Name") (get "Author") " * ")+]
+[+ == "GPL"  +][+(gpl  (get "Name")                " * ")+]
 [+ESAC+] */
 
 #include <iostream>
