@@ -23,13 +23,13 @@
 #include <libanjuta/interfaces/ianjuta-document-manager.h>
 #include <libanjuta/anjuta-shell.h>
 #include <libanjuta/anjuta-debug.h>
-
+#include <glib/gi18n.h>
 #include "plugin.h"
 #include "search-replace.h"
 #include "search-replace_backend.h"
 #include "config.h"
 
-#define UI_FILE PACKAGE_DATA_DIR"/ui/anjuta-search.ui"
+#define UI_FILE PACKAGE_DATA_DIR"/ui/anjuta-search.xml"
 #define ICON_FILE "anjuta-search-plugin-48.png"
 
 static void
