@@ -45,9 +45,10 @@
 #include "symbol-db-view-search.h"
 #include "symbol-db-engine.h"
 #include "symbol-db-prefs.h"
+#include "symbol-db-iface.h"
 
 #define ICON_FILE "anjuta-symbol-db-plugin-48.png"
-#define UI_FILE PACKAGE_DATA_DIR"/ui/anjuta-symbol-db-plugin.ui"
+#define UI_FILE PACKAGE_DATA_DIR"/ui/anjuta-symbol-db-plugin.xml"
 
 #define TIMEOUT_INTERVAL_SYMBOLS_UPDATE		10
 #define TIMEOUT_SECONDS_AFTER_LAST_TIP		5
@@ -317,6 +318,7 @@ static GtkActionEntry actions[] =
 	{
 		"ActionSymbolDBGotoImpl",
 		ANJUTA_STOCK_GOTO_IMPLEMENTATION,
+		/* Translators: Go to the line where the tag is implemented */
 		N_("Tag _Implementation"),
 		"<control>d",
 		N_("Goto symbol definition"),
@@ -325,9 +327,11 @@ static GtkActionEntry actions[] =
 };
 
 static GtkActionEntry actions_search[] = {
-  { "ActionEditSearchFindSymbol", GTK_STOCK_FIND, N_("_Find Symbol..."),
+  { 
+	"ActionEditSearchFindSymbol", GTK_STOCK_FIND, N_("_Find Symbol..."),
 	"<control>l", N_("Find Symbol"),
-    G_CALLBACK (on_find_symbol)}
+    G_CALLBACK (on_find_symbol)
+  }
 };
 
 static void
@@ -348,33 +352,6 @@ enable_view_signals (SymbolDBPlugin *sdb_plugin, gboolean enable, gboolean force
 	}
 }
 
-static void
-on_editor_buffer_symbol_update_scan_end (SymbolDBEngine *dbe, gint process_id, 
-										  gpointer data)
-{
-	SymbolDBPlugin *sdb_plugin;
-	gint i;
-	
-	sdb_plugin = ANJUTA_PLUGIN_SYMBOL_DB (data);	
-	
-	/* search for the proc id */
-	for (i = 0; i < sdb_plugin->buffer_update_ids->len; i++)
-	{
-		if (g_ptr_array_index (sdb_plugin->buffer_update_ids, i) == GINT_TO_POINTER (process_id))
-		{
-			gchar *str;
-			/* hey we found it */
-			/* remove both the items */
-			g_ptr_array_remove_index (sdb_plugin->buffer_update_ids, i);
-			
-			str = (gchar*)g_ptr_array_remove_index (sdb_plugin->buffer_update_files, 
-													i);
-			/* we can now free it */
-			g_free (str);			
-		}
-	}
-}
-
 static gboolean
 on_editor_buffer_symbols_update_timeout (gpointer user_data)
 {
@@ -487,6 +464,76 @@ on_editor_buffer_symbols_update_timeout (gpointer user_data)
 	return proc_id > 0 ? TRUE : FALSE;
 }
 
+static void
+on_editor_buffer_symbol_update_scan_end (SymbolDBEngine *dbe, gint process_id, 
+										  gpointer data)
+{
+	SymbolDBPlugin *sdb_plugin;
+	gint i;
+	
+	sdb_plugin = ANJUTA_PLUGIN_SYMBOL_DB (data);	
+	
+	/* search for the proc id */
+	for (i = 0; i < sdb_plugin->buffer_update_ids->len; i++)
+	{
+		if (g_ptr_array_index (sdb_plugin->buffer_update_ids, i) == GINT_TO_POINTER (process_id))
+		{
+			gchar *str;
+			/* hey we found it */
+			/* remove both the items */
+			g_ptr_array_remove_index (sdb_plugin->buffer_update_ids, i);
+			
+			str = (gchar*)g_ptr_array_remove_index (sdb_plugin->buffer_update_files, 
+													i);
+			/* we can now free it */
+			g_free (str);			
+		}
+	}
+
+	/* was the updating of view-locals symbols blocked while we were scanning?
+	 * e.g. was the editor switched? */
+	if (sdb_plugin->buffer_update_semaphore == TRUE)
+	{
+		GFile *file;
+		gchar *local_path;
+		gboolean tags_update;
+		if (!IANJUTA_IS_EDITOR (sdb_plugin->current_editor))
+			return;
+	
+		file = ianjuta_file_get_file (IANJUTA_FILE (sdb_plugin->current_editor), 
+		    NULL);
+	
+		if (file == NULL)
+			return;
+
+		local_path = g_file_get_path (file);
+	
+		if (local_path == NULL)
+		{
+			g_critical ("local_path == NULL");
+			return;
+		}	
+
+		symbol_db_view_locals_update_list (
+					SYMBOL_DB_VIEW_LOCALS (sdb_plugin->dbv_view_tree_locals),
+					 sdb_plugin->sdbe_project, local_path, FALSE);
+
+		/* add a default timeout to the updating of buffer symbols */	
+		tags_update = anjuta_preferences_get_bool (sdb_plugin->prefs, BUFFER_AUTOSCAN);
+		
+		if (tags_update)
+		{
+			sdb_plugin->buf_update_timeout_id = 
+					g_timeout_add_seconds (TIMEOUT_INTERVAL_SYMBOLS_UPDATE,
+										   on_editor_buffer_symbols_update_timeout,
+										   sdb_plugin);
+		}		
+		
+		g_free (local_path);
+		sdb_plugin->buffer_update_semaphore = FALSE;
+	}	 
+}
+
 static void
 on_editor_destroy (SymbolDBPlugin *sdb_plugin, IAnjutaEditor *editor)
 {
@@ -636,10 +683,33 @@ value_added_current_editor (AnjutaPlugin *plugin, const char *name,
 		g_critical ("local_path == NULL");
 		return;
 	}	
+
+	/* we can have a weird behaviour here if we're not paying the right attention:
+	 * A timeout scan could have been launched and a millisecond later the user could
+	 * have switched editor: we'll be getting the symbol inserted in the previous
+	 * editor into the new one's view.
+	 */
+	if (sdb_plugin->buffer_update_files->len > 0)
+	{
+		sdb_plugin->buffer_update_semaphore = TRUE;
+	}
+	else
+	{
+		symbol_db_view_locals_update_list (
+					SYMBOL_DB_VIEW_LOCALS (sdb_plugin->dbv_view_tree_locals),
+					 sdb_plugin->sdbe_project, local_path, FALSE);
+
+		/* add a default timeout to the updating of buffer symbols */	
+		tags_update = anjuta_preferences_get_bool (sdb_plugin->prefs, BUFFER_AUTOSCAN);
 				
-	symbol_db_view_locals_update_list (
-				SYMBOL_DB_VIEW_LOCALS (sdb_plugin->dbv_view_tree_locals),
-				 sdb_plugin->sdbe_project, local_path, FALSE);
+		if (tags_update)
+		{
+			sdb_plugin->buf_update_timeout_id = 
+					g_timeout_add_seconds (TIMEOUT_INTERVAL_SYMBOLS_UPDATE,
+										   on_editor_buffer_symbols_update_timeout,
+										   plugin);
+		}		
+	}
 				 
 	if (g_hash_table_lookup (sdb_plugin->editor_connected, editor) == NULL)
 	{
@@ -670,14 +740,6 @@ value_added_current_editor (AnjutaPlugin *plugin, const char *name,
 	g_free (uri);
 	g_free (local_path);
 	
-	/* add a default timeout to the updating of buffer symbols */	
-	tags_update = anjuta_preferences_get_int (sdb_plugin->prefs, BUFFER_AUTOSCAN);
-				
-	if (tags_update)
-		sdb_plugin->buf_update_timeout_id = 
-				g_timeout_add_seconds (TIMEOUT_INTERVAL_SYMBOLS_UPDATE,
-									   on_editor_buffer_symbols_update_timeout,
-									   plugin);
 	sdb_plugin->need_symbols_update = FALSE;
 }
 
@@ -898,7 +960,7 @@ do_add_new_files (SymbolDBPlugin *sdb_plugin, const GPtrArray *sources_array,
 			continue;
 		
 		gfile_info = g_file_query_info (gfile, 
-										"*", 
+										"standard::content-type", 
 										G_FILE_QUERY_INFO_NONE,
 										NULL,
 										NULL);
@@ -950,7 +1012,7 @@ do_add_new_files (SymbolDBPlugin *sdb_plugin, const GPtrArray *sources_array,
 		/* ok, we've just tested that the local_filename does exist.
 		 * We can safely add it to the array.
 		 */
-		g_ptr_array_add (languages_array, g_strdup (lang));					
+		g_ptr_array_add (languages_array, g_strdup (lang));
 		g_ptr_array_add (to_scan_array, g_strdup (local_filename));
 		g_object_unref (gfile);
 		g_object_unref (gfile_info);		
@@ -961,7 +1023,7 @@ do_add_new_files (SymbolDBPlugin *sdb_plugin, const GPtrArray *sources_array,
 	 */
 	if (to_scan_array->len > 0)
 	{		
-		gint proc_id = 	symbol_db_engine_add_new_files (sdb_plugin->sdbe_project, 
+		gint proc_id = 	symbol_db_engine_add_new_files_full (sdb_plugin->sdbe_project, 
 					sdb_plugin->project_opened, to_scan_array, languages_array, 
 														   TRUE);
 		
@@ -1065,13 +1127,14 @@ on_system_scan_package_start (SymbolDBEngine *dbe, guint num_files,
 	sdb_plugin->files_count_system_done = 0;
 	sdb_plugin->files_count_system += num_files;	
 	
-	DEBUG_PRINT ("********************* START [%s] with n %d files ", package, num_files);
-	
+		
 	/* show the global bar */
 	gtk_widget_show (sdb_plugin->progress_bar_system);
 	if (sdb_plugin->current_scanned_package != NULL)
 		g_free (sdb_plugin->current_scanned_package);
 	sdb_plugin->current_scanned_package = g_strdup (package);
+	
+	DEBUG_PRINT ("********************* START [%s] with n %d files ", package, num_files);
 }
 
 static void
@@ -1456,9 +1519,9 @@ static gboolean
 do_update_project_symbols (SymbolDBPlugin *sdb_plugin, const gchar *root_dir)
 {
 	gint proc_id;
-	/* Update the symbols */
+	/* Update the symbols */	
 	proc_id = symbol_db_engine_update_project_symbols (sdb_plugin->sdbe_project, 
-														 root_dir);
+														 root_dir, FALSE);
 	if (proc_id > 0)
 	{
 		sdb_plugin->is_project_updating = TRUE;		
@@ -1579,7 +1642,7 @@ do_check_offline_files_changed (SymbolDBPlugin *sdb_plugin)
 				symbol_db_engine_iterator_node_get_symbol_extra_string (dbin,
 													SYMINFO_FILE_PATH);
 			
-			if (g_hash_table_remove (prj_elements_hash, file) == FALSE)
+			if (file && g_hash_table_remove (prj_elements_hash, file) == FALSE)
 			{
 				/* hey, we dind't find an element to remove the the project list.
 				 * So, probably, this is a new file added in offline mode via Makefile.am
@@ -1692,7 +1755,7 @@ on_session_load (AnjutaShell *shell, AnjutaSessionPhase phase,
 		if (sdb_plugin->session_packages == NULL)
 		{
 			/* hey, does user want to import system sources for this project? */
-			gboolean automatic_scan = anjuta_preferences_get_int (sdb_plugin->prefs, 
+			gboolean automatic_scan = anjuta_preferences_get_bool (sdb_plugin->prefs, 
 																  PROJECT_AUTOSCAN);
 			
 			if (automatic_scan == TRUE)
@@ -1702,7 +1765,7 @@ on_session_load (AnjutaShell *shell, AnjutaSessionPhase phase,
 		}
 		
 		/* get preferences about the parallel scan */
-		gboolean parallel_scan = anjuta_preferences_get_int (sdb_plugin->prefs, 
+		gboolean parallel_scan = anjuta_preferences_get_bool (sdb_plugin->prefs, 
 															 PARALLEL_SCAN); 
 		
 		if (parallel_scan == TRUE && 
@@ -1990,8 +2053,7 @@ on_scan_end_manager (SymbolDBEngine *dbe, gint process_id,
 	gint task_registered;
 	
 	task_registered = GPOINTER_TO_INT (g_tree_lookup (sdb_plugin->proc_id_tree, 
-													   GINT_TO_POINTER (process_id)		
-													  ));
+									 GINT_TO_POINTER (process_id)));
 	/* hey, we haven't find anything */
 	if (task_registered <= 0)
 	{
@@ -2014,7 +2076,7 @@ on_scan_end_manager (SymbolDBEngine *dbe, gint process_id,
 										  sdb_plugin);
 			
 			/* get preferences about the parallel scan */
-			gboolean parallel_scan = anjuta_preferences_get_int (sdb_plugin->prefs, 
+			gboolean parallel_scan = anjuta_preferences_get_bool (sdb_plugin->prefs, 
 														 PARALLEL_SCAN); 
 			
 			do_check_languages_count (sdb_plugin);
@@ -2076,7 +2138,7 @@ on_scan_end_manager (SymbolDBEngine *dbe, gint process_id,
  	 * then activate the display of local view
  	 */
 	enable_view_signals (sdb_plugin, TRUE, FALSE);
-	
+
 	if (sdb_plugin->is_offline_scanning == FALSE &&
 		 sdb_plugin->is_project_importing == FALSE &&
 		 sdb_plugin->is_project_updating == FALSE &&
@@ -2084,17 +2146,57 @@ on_scan_end_manager (SymbolDBEngine *dbe, gint process_id,
 	{
 		sdb_plugin->files_count_project_done = 0;
 		sdb_plugin->files_count_project = 0;
-		
 		clear_project_progress_bar (dbe, sdb_plugin);		
 	}	
 }
 
+static void
+on_notebook_button_toggled (GtkToggleButton *button,
+                            SymbolDBPlugin *sdb_plugin)
+{
+	int page = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (button), "__page"));
+	gtk_notebook_set_current_page (GTK_NOTEBOOK(sdb_plugin->dbv_notebook), page);
+}
+
+static void
+on_notebook_switch_page (GtkNotebook* notebook,
+                         GtkNotebookPage* page,
+                         guint page_num,
+                         SymbolDBPlugin *sdb_plugin)
+{
+	g_signal_handlers_block_by_func (sdb_plugin->local_button,
+	                                on_notebook_button_toggled,
+	                                sdb_plugin);
+	g_signal_handlers_block_by_func (sdb_plugin->global_button,
+	                                on_notebook_button_toggled,
+	                                sdb_plugin);
+	g_signal_handlers_block_by_func (sdb_plugin->search_button,
+	                                on_notebook_button_toggled,
+	                                sdb_plugin);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(sdb_plugin->local_button),
+	                              page_num == 0);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(sdb_plugin->global_button),
+	                              page_num == 1);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(sdb_plugin->search_button),
+	                              page_num == 2);
+	g_signal_handlers_unblock_by_func (sdb_plugin->local_button,
+	                                on_notebook_button_toggled,
+	                                sdb_plugin);
+	g_signal_handlers_unblock_by_func (sdb_plugin->global_button,
+	                                on_notebook_button_toggled,
+	                                sdb_plugin);
+	g_signal_handlers_unblock_by_func (sdb_plugin->search_button,
+	                                on_notebook_button_toggled,
+	                                sdb_plugin);
+}
+
 static gboolean
 symbol_db_activate (AnjutaPlugin *plugin)
 {
 	SymbolDBPlugin *sdb_plugin;
 	gchar *anjuta_cache_path;
 	gchar *ctags_path;
+	GtkWidget *label;
 	
 	DEBUG_PRINT ("SymbolDBPlugin: Activating SymbolDBPlugin plugin ...");
 	
@@ -2108,8 +2210,11 @@ symbol_db_activate (AnjutaPlugin *plugin)
 	sdb_plugin->prefs = anjuta_shell_get_preferences (plugin->shell, NULL);
 	sdb_plugin->project_opened = NULL;
 
-	ctags_path = anjuta_preferences_get (sdb_plugin->prefs, CTAGS_PREFS_KEY); 
+	ctags_path = NULL;
 
+	/* leaving here this code. Maybe in future ctags-devs will include our patches
+	 * upstream and this can be useful again.
+	 */
 	if (ctags_path == NULL) 
 	{
 		DEBUG_PRINT ("ctags is not in preferences. Trying a default one %s", 
@@ -2134,6 +2239,7 @@ symbol_db_activate (AnjutaPlugin *plugin)
 	 */
 	sdb_plugin->buffer_update_files = g_ptr_array_new ();
 	sdb_plugin->buffer_update_ids = g_ptr_array_new ();
+	sdb_plugin->buffer_update_semaphore = FALSE;
 	
 	sdb_plugin->is_offline_scanning = FALSE;
 	sdb_plugin->is_project_importing = FALSE;
@@ -2188,13 +2294,79 @@ symbol_db_activate (AnjutaPlugin *plugin)
 	
 	g_signal_connect (G_OBJECT (sdb_plugin->sdbe_project), "scan-end",
 		  		G_CALLBACK (on_scan_end_manager), sdb_plugin);
+
+	/* connect signals for interface to receive them */
+	g_signal_connect (G_OBJECT (sdb_plugin->sdbe_globals), "symbol-inserted",
+				G_CALLBACK (on_isymbol_manager_sys_symbol_inserted), sdb_plugin);
+
+	g_signal_connect (G_OBJECT (sdb_plugin->sdbe_globals), "symbol-updated",
+				G_CALLBACK (on_isymbol_manager_sys_symbol_updated), sdb_plugin);
+
+	g_signal_connect (G_OBJECT (sdb_plugin->sdbe_globals), "symbol-removed",
+				G_CALLBACK (on_isymbol_manager_sys_symbol_removed), sdb_plugin);
+
+	g_signal_connect (G_OBJECT (sdb_plugin->sdbe_globals), "scan-end",
+				G_CALLBACK (on_isymbol_manager_sys_scan_end), sdb_plugin);
 	
-	/* sets preferences to NULL, it'll be instantiated when required.\ */
+	g_signal_connect (G_OBJECT (sdb_plugin->sdbe_project), "symbol-inserted",
+				G_CALLBACK (on_isymbol_manager_prj_symbol_inserted), sdb_plugin);
+
+	g_signal_connect (G_OBJECT (sdb_plugin->sdbe_project), "symbol-updated",
+				G_CALLBACK (on_isymbol_manager_prj_symbol_updated), sdb_plugin);
+
+	g_signal_connect (G_OBJECT (sdb_plugin->sdbe_project), "symbol-removed",
+				G_CALLBACK (on_isymbol_manager_prj_symbol_inserted), sdb_plugin);
+	
+	g_signal_connect (G_OBJECT (sdb_plugin->sdbe_project), "scan-end",
+				G_CALLBACK (on_isymbol_manager_prj_scan_end), sdb_plugin);
+
+	
+	/* sets preferences to NULL, it'll be instantiated when required. */
 	sdb_plugin->sdbp = NULL;
 	
 	/* Create widgets */
 	sdb_plugin->dbv_main = gtk_vbox_new(FALSE, 5);
 	sdb_plugin->dbv_notebook = gtk_notebook_new();
+	gtk_notebook_set_show_tabs (GTK_NOTEBOOK (sdb_plugin->dbv_notebook), FALSE);
+	sdb_plugin->dbv_hbox = gtk_hbox_new (FALSE, 1);
+
+	sdb_plugin->local_button = gtk_toggle_button_new_with_label (_("Local"));
+	sdb_plugin->global_button = gtk_toggle_button_new_with_label (_("Global"));
+	sdb_plugin->search_button = gtk_toggle_button_new_with_label (_("Search"));
+
+	g_object_set_data (G_OBJECT(sdb_plugin->local_button), "__page", GINT_TO_POINTER(0));
+	g_object_set_data (G_OBJECT(sdb_plugin->global_button), "__page", GINT_TO_POINTER(1));
+	g_object_set_data (G_OBJECT(sdb_plugin->search_button), "__page", GINT_TO_POINTER(2));
+
+	g_signal_connect (sdb_plugin->local_button, "toggled", G_CALLBACK(on_notebook_button_toggled),
+	                  sdb_plugin);
+	g_signal_connect (sdb_plugin->global_button, "toggled", G_CALLBACK(on_notebook_button_toggled),
+	                  sdb_plugin);
+	g_signal_connect (sdb_plugin->search_button, "toggled", G_CALLBACK(on_notebook_button_toggled),
+	                  sdb_plugin);
+	g_signal_connect (sdb_plugin->dbv_notebook,
+	                  "switch-page",
+	                  G_CALLBACK(on_notebook_switch_page),
+	                  sdb_plugin);
+
+	label = gtk_label_new (_("Symbols"));
+	gtk_label_set_ellipsize (GTK_LABEL (label),
+	                         PANGO_ELLIPSIZE_END);
+	gtk_box_pack_start (GTK_BOX(sdb_plugin->dbv_hbox), 
+	                    gtk_image_new_from_stock ("symbol-db-plugin-icon",
+	                                              GTK_ICON_SIZE_MENU),
+	                    FALSE, FALSE, 0);	
+	gtk_box_pack_start (GTK_BOX(sdb_plugin->dbv_hbox), label,
+	                    TRUE, TRUE, 0);	
+	gtk_box_pack_start (GTK_BOX(sdb_plugin->dbv_hbox), sdb_plugin->local_button,
+	                    FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX(sdb_plugin->dbv_hbox), sdb_plugin->global_button,
+	                    FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX(sdb_plugin->dbv_hbox), sdb_plugin->search_button,
+	                    FALSE, FALSE, 0);
+
+	gtk_widget_show_all (sdb_plugin->dbv_hbox);
+	
 	sdb_plugin->progress_bar_project = gtk_progress_bar_new();
 	gtk_progress_bar_set_ellipsize (GTK_PROGRESS_BAR(sdb_plugin->progress_bar_project),
 									PANGO_ELLIPSIZE_MIDDLE);
@@ -2204,7 +2376,7 @@ symbol_db_activate (AnjutaPlugin *plugin)
 	gtk_progress_bar_set_ellipsize (GTK_PROGRESS_BAR(sdb_plugin->progress_bar_system),
 									PANGO_ELLIPSIZE_MIDDLE);
 	g_object_ref (sdb_plugin->progress_bar_system);
-		
+	
 	gtk_box_pack_start (GTK_BOX (sdb_plugin->dbv_main), sdb_plugin->dbv_notebook,
 						TRUE, TRUE, 0);
 	gtk_box_pack_start (GTK_BOX (sdb_plugin->dbv_main), sdb_plugin->progress_bar_project,
@@ -2304,10 +2476,11 @@ symbol_db_activate (AnjutaPlugin *plugin)
 								 value_added_current_editor,
 								 value_removed_current_editor, NULL);
 	/* Added widgets */
-	anjuta_shell_add_widget (plugin->shell, sdb_plugin->dbv_main,
-							 "AnjutaSymbolDB", _("Symbols"),
-							 "symbol-db-plugin-icon",
-							 ANJUTA_SHELL_PLACEMENT_LEFT, NULL);	
+	anjuta_shell_add_widget_custom (plugin->shell, sdb_plugin->dbv_main,
+	                                "AnjutaSymbolDB", _("Symbols"),
+	                                "symbol-db-plugin-icon",
+	                                sdb_plugin->dbv_hbox,
+	                                ANJUTA_SHELL_PLACEMENT_LEFT, NULL);	
 
 	/* Add action group */
 	sdb_plugin->popup_action_group = 
@@ -2403,6 +2576,33 @@ symbol_db_deactivate (AnjutaPlugin *plugin)
 	g_signal_handlers_disconnect_by_func (G_OBJECT (sdb_plugin->sdbs),
 										  on_scan_end_manager,
 										  plugin);
+
+	/* disconnect the interface ones */
+	/* connect signals for interface to receive them */
+	g_signal_handlers_disconnect_by_func (G_OBJECT (sdb_plugin->sdbe_globals),
+				G_CALLBACK (on_isymbol_manager_sys_symbol_inserted), plugin);
+
+	g_signal_handlers_disconnect_by_func (G_OBJECT (sdb_plugin->sdbe_globals),
+				G_CALLBACK (on_isymbol_manager_sys_symbol_updated), plugin);
+
+	g_signal_handlers_disconnect_by_func (G_OBJECT (sdb_plugin->sdbe_globals),
+				G_CALLBACK (on_isymbol_manager_sys_symbol_removed), plugin);
+
+	g_signal_handlers_disconnect_by_func (G_OBJECT (sdb_plugin->sdbe_globals),
+				G_CALLBACK (on_isymbol_manager_sys_scan_end), plugin);
+	
+	g_signal_handlers_disconnect_by_func (G_OBJECT (sdb_plugin->sdbe_project),
+				G_CALLBACK (on_isymbol_manager_prj_symbol_inserted), plugin);
+
+	g_signal_handlers_disconnect_by_func (G_OBJECT (sdb_plugin->sdbe_project), 
+				G_CALLBACK (on_isymbol_manager_prj_symbol_updated), plugin);
+
+	g_signal_handlers_disconnect_by_func (G_OBJECT (sdb_plugin->sdbe_project),
+				G_CALLBACK (on_isymbol_manager_prj_symbol_inserted), plugin);
+	
+	g_signal_handlers_disconnect_by_func (G_OBJECT (sdb_plugin->sdbe_project),
+				G_CALLBACK (on_isymbol_manager_prj_scan_end), plugin);
+	
 	if (sdb_plugin->update_timer)
 	{
 		g_timer_destroy (sdb_plugin->update_timer);
@@ -2546,377 +2746,6 @@ symbol_db_class_init (GObjectClass *klass)
 						g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);	
 }
 
-static IAnjutaIterable*
-isymbol_manager_search (IAnjutaSymbolManager *sm,
-						IAnjutaSymbolType match_types,
-						gboolean include_types,
-						IAnjutaSymbolField info_fields,
-						const gchar *match_name,
-						gboolean partial_name_match,
-						gboolean global_symbols_search,
-						gboolean global_tags_search,
-						gint results_limit,
-						gint results_offset,
-						GError **err)
-{
-	SymbolDBEngineIterator *iterator = NULL;
-	SymbolDBPlugin *sdb_plugin;
-	SymbolDBEngine *dbe_project;
-	SymbolDBEngine *dbe_globals;
-	GPtrArray *filter_array;
-	gchar *pattern;
-	gboolean exact_match = !partial_name_match;
-
-	sdb_plugin = ANJUTA_PLUGIN_SYMBOL_DB (sm);
-	dbe_project = SYMBOL_DB_ENGINE (sdb_plugin->sdbe_project);
-	dbe_globals = SYMBOL_DB_ENGINE (sdb_plugin->sdbe_globals);
-	
-	if (match_types & IANJUTA_SYMBOL_TYPE_UNDEF)
-	{
-		filter_array = NULL;
-		/*DEBUG_PRINT ("%s", "filter_array is NULL");*/
-	}
-	else 
-	{
-		filter_array = symbol_db_util_fill_type_array (match_types);
-		/*DEBUG_PRINT ("filter_array filled with %d kinds", filter_array->len);*/
-	}
-
-	if (exact_match == FALSE)
-		pattern = g_strdup_printf ("%s%%", match_name == NULL ? "" : match_name);
-	else
-	{
-		if (match_name == NULL)
-			pattern = NULL;
-		else
-			pattern = g_strdup_printf ("%s", match_name);
-	}
-	
-	/* should we lookup for project of system tags? */
-	iterator = 
-		symbol_db_engine_find_symbol_by_name_pattern_filtered (
-					global_tags_search == FALSE ? dbe_project : dbe_globals, 
-					pattern,
-					exact_match,
-					filter_array,
-					include_types,
-					global_symbols_search,
-					global_tags_search == FALSE ? NULL : sdb_plugin->session_packages,
-					results_limit,
-					results_offset,
-					info_fields);	
-	g_free (pattern);
-	
-	if (filter_array)
-	{
-		g_ptr_array_foreach (filter_array, (GFunc)g_free, NULL);
-		g_ptr_array_free (filter_array, TRUE);
-	}
-	return IANJUTA_ITERABLE (iterator);
-}
-
-static IAnjutaIterable*
-isymbol_manager_get_members (IAnjutaSymbolManager *sm,
-							 const IAnjutaSymbol *symbol, 
-							 IAnjutaSymbolField info_fields,
-							 gboolean global_search,
-							 GError **err)
-{
-	SymbolDBEngineIteratorNode *node;
-	SymbolDBPlugin *sdb_plugin;
-	SymbolDBEngine *dbe;
-	gint sym_id;
-	SymbolDBEngineIterator *iterator;
-
-	sdb_plugin = ANJUTA_PLUGIN_SYMBOL_DB (sm);
-	dbe = SYMBOL_DB_ENGINE (sdb_plugin->sdbe_project);	
-	node = SYMBOL_DB_ENGINE_ITERATOR_NODE (symbol);
-	
-	sym_id = symbol_db_engine_iterator_node_get_symbol_id (node);
-	
-	iterator = symbol_db_engine_get_scope_members_by_symbol_id (dbe,
-																sym_id,
-																-1, 
-																-1,
-																info_fields);
-	return IANJUTA_ITERABLE (iterator);
-}
-
-static IAnjutaIterable*
-isymbol_manager_get_class_parents (IAnjutaSymbolManager *sm,
-							 const IAnjutaSymbol *symbol,
-							 IAnjutaSymbolField info_fields,
-							 GError **err)
-{
-	SymbolDBEngineIteratorNode *node;
-	SymbolDBPlugin *sdb_plugin;
-	SymbolDBEngine *dbe;
-	gint sym_id;
-	SymbolDBEngineIterator *iterator;
-
-	sdb_plugin = ANJUTA_PLUGIN_SYMBOL_DB (sm);
-	dbe = SYMBOL_DB_ENGINE (sdb_plugin->sdbe_project);
-	
-	node = SYMBOL_DB_ENGINE_ITERATOR_NODE (symbol);
-	
-	sym_id = symbol_db_engine_iterator_node_get_symbol_id (node);
-	
-	iterator = symbol_db_engine_get_class_parents_by_symbol_id (dbe, 
-																sym_id, 
-																info_fields);
-	return IANJUTA_ITERABLE (iterator);
-}
-
-static IAnjutaIterable*
-isymbol_manager_get_scope (IAnjutaSymbolManager *sm,
-						   const gchar* filename,  
-						   gulong line,  
-						   IAnjutaSymbolField info_fields, 
-						   GError **err)
-{
-	SymbolDBPlugin *sdb_plugin;
-	SymbolDBEngine *dbe;
-	SymbolDBEngineIterator *iterator;
-
-	sdb_plugin = ANJUTA_PLUGIN_SYMBOL_DB (sm);
-	dbe = SYMBOL_DB_ENGINE (sdb_plugin->sdbe_project);
-	
-	iterator = symbol_db_engine_get_current_scope (dbe, filename, line, info_fields);
-	
-	return IANJUTA_ITERABLE (iterator);
-}
-
-static IAnjutaIterable*
-isymbol_manager_get_parent_scope (IAnjutaSymbolManager *sm,
-								  const IAnjutaSymbol *symbol, 
-								  const gchar *filename, 
-								  IAnjutaSymbolField info_fields,
-								  GError **err)
-{
-	SymbolDBEngineIteratorNode *node;
-	gint child_node_id, parent_node_id;
-	SymbolDBPlugin *sdb_plugin;
-	SymbolDBEngine *dbe;
-	SymbolDBEngineIterator *iterator;
-
-	sdb_plugin = ANJUTA_PLUGIN_SYMBOL_DB (sm);
-	dbe = SYMBOL_DB_ENGINE (sdb_plugin->sdbe_project);
-
-	node = SYMBOL_DB_ENGINE_ITERATOR_NODE (symbol);
-	
-	child_node_id = symbol_db_engine_iterator_node_get_symbol_id (node);
-	
-	if (child_node_id <= 0)
-		return NULL;
-	
-	parent_node_id = symbol_db_engine_get_parent_scope_id_by_symbol_id (dbe,
-									child_node_id,
-									filename);
-
-	iterator = symbol_db_engine_get_symbol_info_by_id (dbe, parent_node_id, 
-													   info_fields);
-	return IANJUTA_ITERABLE (iterator);
-}
-
-static IAnjutaIterable*
-isymbol_manager_get_symbol_more_info (IAnjutaSymbolManager *sm,
-								  const IAnjutaSymbol *symbol, 
-								  IAnjutaSymbolField info_fields,
-								  GError **err)
-{
-	SymbolDBEngineIteratorNode *node;
-	gint node_id;
-	SymbolDBPlugin *sdb_plugin;
-	SymbolDBEngine *dbe;
-	SymbolDBEngineIterator *iterator;
-
-	sdb_plugin = ANJUTA_PLUGIN_SYMBOL_DB (sm);
-	dbe = SYMBOL_DB_ENGINE (sdb_plugin->sdbe_project);
-
-	node = SYMBOL_DB_ENGINE_ITERATOR_NODE (symbol);
-	
-	node_id = symbol_db_engine_iterator_node_get_symbol_id (node);
-	
-	if (node_id <= 0)
-		return NULL;
-	
-	iterator = symbol_db_engine_get_symbol_info_by_id (dbe, node_id, info_fields);	
-	
-	return IANJUTA_ITERABLE (iterator);
-}
-
-static IAnjutaSymbol*
-isymbol_manager_get_symbol_by_id (IAnjutaSymbolManager *sm,
-								  gint symbol_id, 
-								  IAnjutaSymbolField info_fields,
-								  GError **err)
-{
-	SymbolDBEngineIteratorNode *node;
-	SymbolDBPlugin *sdb_plugin;
-	SymbolDBEngine *dbe;
-	SymbolDBEngineIterator *iterator;
-
-	g_return_val_if_fail (symbol_id > 0, NULL);
-	sdb_plugin = ANJUTA_PLUGIN_SYMBOL_DB (sm);
-	dbe = SYMBOL_DB_ENGINE (sdb_plugin->sdbe_project);
-
-	iterator = symbol_db_engine_get_symbol_info_by_id (dbe, symbol_id, 
-													   info_fields);	
-	
-	if (iterator == NULL)
-		return NULL;
-	
-	node = SYMBOL_DB_ENGINE_ITERATOR_NODE (iterator);
-	return IANJUTA_SYMBOL (node);
-}
-
-static IAnjutaIterable* 
-isymbol_manager_search_system (IAnjutaSymbolManager *sm, IAnjutaSymbolType match_types, 
-				gboolean include_types,  IAnjutaSymbolField info_fields, const gchar *pattern, 
-			   gint results_limit, gint results_offset, GError **err)
-{
-	SymbolDBPlugin *sdb_plugin;
-	SymbolDBEngine *dbe;
-	SymbolDBEngineIterator *iterator;
-	gboolean exact_match;
-	GPtrArray *filter_array;
-	g_return_val_if_fail (pattern != NULL, NULL);
-	
-	sdb_plugin = ANJUTA_PLUGIN_SYMBOL_DB (sm);
-	dbe = SYMBOL_DB_ENGINE (sdb_plugin->sdbe_globals);
-	
-	exact_match = symbol_db_util_is_pattern_exact_match (pattern);
-
-	if (match_types & IANJUTA_SYMBOL_TYPE_UNDEF)
-	{
-		filter_array = NULL;
-	}
-	else 
-	{
-		filter_array = symbol_db_util_fill_type_array (match_types);
-	}
-	
-	iterator = 		
-		symbol_db_engine_find_symbol_by_name_pattern_filtered (dbe,
-					pattern,
-					exact_match,
-					filter_array,
-					include_types,
-					1,
-					sdb_plugin->session_packages,
-					results_limit,
-					results_offset,
-					info_fields);	
-	
-	return IANJUTA_ITERABLE (iterator);
-}	
-			
-
-static IAnjutaIterable* 
-isymbol_manager_search_project (IAnjutaSymbolManager *sm, IAnjutaSymbolType match_types, 
-				gboolean include_types,  IAnjutaSymbolField info_fields, const gchar *pattern, 
-				gint results_limit, gint results_offset, GError **err)
-{
-	SymbolDBPlugin *sdb_plugin;
-	SymbolDBEngine *dbe;
-	SymbolDBEngineIterator *iterator;
-	gboolean exact_match;
-	GPtrArray *filter_array;
-
-	g_return_val_if_fail (pattern != NULL, NULL);
-	
-	sdb_plugin = ANJUTA_PLUGIN_SYMBOL_DB (sm);
-	dbe = SYMBOL_DB_ENGINE (sdb_plugin->sdbe_project);
-	
-	exact_match = symbol_db_util_is_pattern_exact_match (pattern);
-
-	if (match_types & IANJUTA_SYMBOL_TYPE_UNDEF)
-	{
-		filter_array = NULL;
-	}
-	else 
-	{
-		filter_array = symbol_db_util_fill_type_array (match_types);
-	}
-	
-	iterator = 		
-		symbol_db_engine_find_symbol_by_name_pattern_filtered (dbe,
-				    pattern,
-					exact_match,
-					filter_array,
-					include_types,
-					1,
-					NULL,
-					results_limit,
-					results_offset,
-					info_fields);
-	
-	return IANJUTA_ITERABLE (iterator);
-}
-	
-	
-static IAnjutaIterable* 
-isymbol_manager_search_file (IAnjutaSymbolManager *sm, IAnjutaSymbolType match_types, 
-				gboolean include_types,  IAnjutaSymbolField info_fields, const gchar *pattern, 
-			 	const GFile *file, gint results_limit, gint results_offset, GError **err)
-{
-	SymbolDBPlugin *sdb_plugin;
-	SymbolDBEngine *dbe;
-	SymbolDBEngineIterator *iterator;
-	GPtrArray *filter_array;
-	gchar *abs_file_path;
-
-	g_return_val_if_fail (pattern != NULL, NULL);
-	
-	sdb_plugin = ANJUTA_PLUGIN_SYMBOL_DB (sm);
-	dbe = SYMBOL_DB_ENGINE (sdb_plugin->sdbe_project);
-	
-	abs_file_path = g_file_get_path ((GFile *)file);
-
-	if (abs_file_path == NULL)
-	{
-		g_warning ("isymbol_manager_search_file (): GFile has no absolute path");
-		return NULL;
-	}
-	
-	if (match_types & IANJUTA_SYMBOL_TYPE_UNDEF)
-	{
-		filter_array = NULL;
-	}
-	else 
-	{
-		filter_array = symbol_db_util_fill_type_array (match_types);
-	}
-	
-	iterator = 		
-		symbol_db_engine_find_symbol_by_name_pattern_on_file (dbe,
-				    pattern,
-					abs_file_path,
-					filter_array,
-					include_types,
-					results_limit,
-					results_offset,
-					info_fields);
-	
-	g_free (abs_file_path);
-	
-	return IANJUTA_ITERABLE (iterator);
-}
-
-static void
-isymbol_manager_iface_init (IAnjutaSymbolManagerIface *iface)
-{
-	iface->search = isymbol_manager_search;
-	iface->get_members = isymbol_manager_get_members;
-	iface->get_class_parents = isymbol_manager_get_class_parents;
-	iface->get_scope = isymbol_manager_get_scope;
-	iface->get_parent_scope = isymbol_manager_get_parent_scope;
-	iface->get_symbol_more_info = isymbol_manager_get_symbol_more_info;
-	iface->get_symbol_by_id = isymbol_manager_get_symbol_by_id;
-	iface->search_system = isymbol_manager_search_system;
-	iface->search_project = isymbol_manager_search_project;
-	iface->search_file = isymbol_manager_search_file;
-}
 
 
 static void
@@ -2982,8 +2811,7 @@ on_prefs_buffer_update_toggled (SymbolDBPrefs *sdbp, guint value,
 									   on_editor_buffer_symbols_update_timeout,
 									   sdb_plugin);			
 		
-	}
-	
+	}	
 }
 
 static void
