@@ -1,7 +1,7 @@
 /* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 4; tab-width: 4 -*- */
 /*
  * anjuta
- * Copyright (C) Massimo Cora' 2007 <maxcvs@email.it>
+ * Copyright (C) Massimo Cora' 2007-2008 <maxcvs@email.it>
  * 
  * anjuta is free software.
  * 
@@ -28,6 +28,8 @@
 #include <glib-object.h>
 #include <libgda/libgda.h>
 
+#include "symbol-db-engine-priv.h"
+
 G_BEGIN_DECLS
 
 #define SYMBOL_TYPE_DB_ENGINE_ITERATOR_NODE             (sdb_engine_iterator_node_get_type ())
@@ -53,7 +55,7 @@ struct _SymbolDBEngineIteratorNodeClass
 	GObjectClass parent_class;
 };
 
-
+ 
 GType sdb_engine_iterator_node_get_type (void) G_GNUC_CONST;
 
 gint
@@ -71,12 +73,15 @@ symbol_db_engine_iterator_node_get_symbol_is_file_scope (SymbolDBEngineIteratorN
 const gchar* 
 symbol_db_engine_iterator_node_get_symbol_signature (SymbolDBEngineIteratorNode *dbin);
 
+const gchar* 
+symbol_db_engine_iterator_node_get_symbol_returntype (SymbolDBEngineIteratorNode *dbin);
+
 /* just one SYMINFO_* per time. It is NOT possible to pass something like
  * SYMINFO_1 | SYMINFO_2 | ...
  */
 const gchar*
 symbol_db_engine_iterator_node_get_symbol_extra_string (SymbolDBEngineIteratorNode *dbin,
-												   gint sym_info);
+												   SymExtraInfo sym_info);
 
 void
 symbol_db_engine_iterator_node_set_data (SymbolDBEngineIteratorNode *dbin,
@@ -86,6 +91,10 @@ void
 symbol_db_engine_iterator_node_set_conversion_hash (SymbolDBEngineIteratorNode *dbin,
 										 const GHashTable *sym_type_conversion_hash);
 
+void
+symbol_db_engine_iterator_node_set_prj_directory (SymbolDBEngineIteratorNode *dbin,
+										const gchar *prj_directory);
+
 SymbolDBEngineIteratorNode *
 symbol_db_engine_iterator_node_new (const GdaDataModelIter *data);
 
