@@ -25,7 +25,8 @@
  *---------------------------------------------------------------------------*/
 
 #include <config.h>
-
+#include <errno.h>
+#include <sys/stat.h>
 #include "editor.h"
 
 #include "dialog.h"
@@ -36,9 +37,12 @@
 #include <libanjuta/interfaces/ianjuta-document-manager.h>
 #include <libanjuta/interfaces/ianjuta-editor.h>
 #include <libanjuta/interfaces/ianjuta-file-loader.h>
-
+#include <glib.h>
+#include <gdk/gdk.h>
 #include <gtk/gtk.h>
-
+#include <sys/types.h>
+#include <fcntl.h>
+#include <unistd.h>
 #include <string.h>
 
 /*---------------------------------------------------------------------------*/
@@ -88,7 +92,7 @@ struct _ATPToolEditor
 	ATPVariableDialog input_file_var;
 	ATPVariableDialog input_string_var;
 	GtkToggleButton *shortcut_bt;
-	GnomeIconEntry *icon_en;
+	GtkButton *icon_en;
 	gchar* shortcut;
 	ATPUserTool *tool;
 	ATPToolDialog* parent;
@@ -117,20 +121,25 @@ struct _ATPToolEditor
 #define TOOL_INPUT_VARIABLE "input_button"
 #define TOOL_SHORTCUT "shortcut_bt"
 #define TOOL_ICON "icon_entry"
-
-#define EDITOR_RESPONSE_SIGNAL "on_editor_dialog_response"
-#define EDITOR_PARAM_VARIABLE_SIGNAL "on_variable_parameter"
-#define EDITOR_DIR_VARIABLE_SIGNAL "on_variable_directory"
-#define EDITOR_INPUT_VARIABLE_SIGNAL "on_variable_input"
-#define EDITOR_INPUT_CHANGED_SIGNAL "on_input_changed"
-#define EDITOR_TOGGLE_TERMINAL_SIGNAL "on_toggle_terminal"
-#define EDITOR_TOGGLE_SHORCUT_SIGNAL "on_toggle_shorcut"
-#define EDITOR_TOGGLE_SCRIPT_SIGNAL "on_toggle_script"
-
+#define TOOL_BROWSE_WORKING_DIR "browse_button_directory_entry"
+#define TOOL_BROWSE_COMMAND "browse_button_command_entry"
 #define TOOL_VARIABLE "variable_dialog"
 #define VARIABLE_TREEVIEW "variable_treeview"
-#define VARIABLE_RESPONSE_SIGNAL "on_variable_dialog_response"
-#define VARIABLE_ACTIVATE_SIGNAL "on_variable_activate_row"
+
+void atp_on_variable_activate_row (GtkTreeView *treeview, GtkTreePath *path, GtkTreeViewColumn *column, gpointer user_data);
+void atp_on_variable_dialog_response (GtkDialog *dialog, gint response, gpointer user_data);
+void atp_on_editor_icon_entry_clicked (GtkButton *button, gpointer user_data);
+void atp_on_editor_terminal_toggle (GtkToggleButton *tb, gpointer user_data);
+void atp_on_editor_script_toggle (GtkToggleButton *tb, gpointer user_data);
+void atp_on_editor_input_changed (GtkComboBox *combo, gpointer user_data);
+void atp_on_editor_dialog_response (GtkDialog *dialog, gint response, gpointer user_data);
+void atp_on_editor_param_variable_show (GtkButton *button, gpointer user_data);
+void atp_on_editor_dir_variable_show (GtkButton *button, gpointer user_data);
+void atp_on_editor_input_variable_show (GtkButton *button, gpointer user_data);
+void atp_on_editor_shortcut_toggle (GtkToggleButton *tb, gpointer user_data);
+void atp_on_editor_browse_button_clicked (GtkButton *button, GtkEntry *entry);
+void atp_on_editor_browse_button_dir_clicked (GtkButton *button, GtkEntry *entry);
+
 
 /* Add helper function
  *---------------------------------------------------------------------------*/
@@ -184,6 +193,7 @@ static void
 set_combo_box_enum_model (GtkComboBox* combo_box, const ATPEnumType* list)
 {
 	GtkTreeModel *model;
+	GtkCellRenderer * renderer;
 
 	model = GTK_TREE_MODEL (gtk_list_store_new (2, G_TYPE_STRING, G_TYPE_INT));
 
@@ -195,6 +205,10 @@ set_combo_box_enum_model (GtkComboBox* combo_box, const ATPEnumType* list)
 		gtk_list_store_set (GTK_LIST_STORE(model), &iter, 0, _(list->name), 1, list->id, -1);
 	}
 	gtk_combo_box_set_model (combo_box, model);
+	renderer = gtk_cell_renderer_text_new();
+	gtk_cell_layout_clear (GTK_CELL_LAYOUT(combo_box));
+    gtk_cell_layout_pack_start (GTK_CELL_LAYOUT(combo_box), renderer, TRUE);
+    gtk_cell_layout_add_attribute (GTK_CELL_LAYOUT(combo_box), renderer, "text", 0 );
 }
 
 static gint
@@ -384,8 +398,8 @@ get_current_name (GtkTreeView *view)
 	return NULL;
 }
 
-static void
-on_variable_activate (GtkTreeView *treeview, GtkTreePath *path, GtkTreeViewColumn *column, gpointer user_data)
+void
+atp_on_variable_activate_row (GtkTreeView *treeview, GtkTreePath *path, GtkTreeViewColumn *column, gpointer user_data)
 {
 	ATPVariableDialog *this = (ATPVariableDialog*)user_data;
 	GtkTreeIter iter;
@@ -402,8 +416,8 @@ on_variable_activate (GtkTreeView *treeview, GtkTreePath *path, GtkTreeViewColum
 	gtk_widget_hide (GTK_WIDGET (this->dialog));
 }
 
-static void
-on_variable_response (GtkDialog *dialog, gint response, gpointer user_data)
+void
+atp_on_variable_dialog_response (GtkDialog *dialog, gint response, gpointer user_data)
 {
 	ATPVariableDialog *this = (ATPVariableDialog *)user_data;
 	gchar* name;
@@ -424,7 +438,7 @@ on_variable_response (GtkDialog *dialog, gint response, gpointer user_data)
 static gboolean
 atp_variable_dialog_show (ATPVariableDialog* this, ATPFlags flag)
 {
-	GladeXML *xml;
+	GtkBuilder *bxml;
 	GtkTreeModel *model;
 	GtkCellRenderer *renderer;
 	GtkTreeViewColumn *column;
@@ -435,18 +449,18 @@ atp_variable_dialog_show (ATPVariableDialog* this, ATPFlags flag)
 		if (this->dialog) gtk_window_present (GTK_WINDOW (this->dialog));
 		return TRUE;
 	}
+
+	bxml = anjuta_util_builder_new (GLADE_FILE, NULL);
+	if (!bxml) return FALSE;
+	anjuta_util_builder_get_objects (bxml,
+	    TOOL_VARIABLE, &this->dialog,
+	    VARIABLE_TREEVIEW, &this->view,
+	    NULL);
 	
-	if (NULL == (xml = glade_xml_new(GLADE_FILE, TOOL_VARIABLE, NULL)))
-	{
-		anjuta_util_dialog_error (GTK_WINDOW (this->editor->dialog), _("Unable to build user interface for tool variable"));
-		return FALSE;
-	}
-	this->dialog = GTK_DIALOG (glade_xml_get_widget(xml, TOOL_VARIABLE));
 	gtk_widget_show (GTK_WIDGET (this->dialog));
 	gtk_window_set_transient_for (GTK_WINDOW (this->dialog), GTK_WINDOW (this->editor->dialog));
 
 	/* Create variable list */
-	this->view = GTK_TREE_VIEW (glade_xml_get_widget(xml, VARIABLE_TREEVIEW));
 	model = GTK_TREE_MODEL (gtk_list_store_new (ATP_N_VARIABLE_COLUMNS, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING));
 	gtk_tree_view_set_model (this->view, model);
 
@@ -462,12 +476,11 @@ atp_variable_dialog_show (ATPVariableDialog* this, ATPFlags flag)
 	g_object_unref (model);
 	atp_variable_dialog_populate (this, flag);
 
-	/* Connect all signals */	
-	glade_xml_signal_connect_data (xml, VARIABLE_RESPONSE_SIGNAL, GTK_SIGNAL_FUNC (on_variable_response), this);
-	glade_xml_signal_connect_data (xml, VARIABLE_ACTIVATE_SIGNAL, GTK_SIGNAL_FUNC (on_variable_activate), this);
+	/* Connect all signals */
+	gtk_builder_connect_signals (bxml, this);
 	g_signal_connect (G_OBJECT (this->dialog), "delete_event", G_CALLBACK (gtk_widget_hide_on_delete), NULL);
 
-	g_object_unref (xml);
+	g_object_unref (bxml);
 
 	return TRUE;
 }
@@ -475,6 +488,80 @@ atp_variable_dialog_show (ATPVariableDialog* this, ATPFlags flag)
 /* Tool editor dialog
  *---------------------------------------------------------------------------*/
 
+static void
+cb_preview_update (GtkFileChooser *fc,
+		   GtkImage *preview)
+{
+	char *filename;
+	GdkPixbuf *pixbuf;
+
+	filename = gtk_file_chooser_get_preview_filename (fc);
+	if (filename) {
+		pixbuf = gdk_pixbuf_new_from_file (filename, NULL);
+
+		gtk_file_chooser_set_preview_widget_active (fc, pixbuf != NULL);
+		
+		if (pixbuf) {
+			gtk_image_set_from_pixbuf (preview, pixbuf);
+			g_object_unref (pixbuf);
+		}
+		
+		g_free (filename);
+	}
+}
+
+void
+atp_on_editor_icon_entry_clicked (GtkButton *button, gpointer user_data)
+{
+	ATPToolEditor *this = (ATPToolEditor *)user_data;
+	GtkWidget *dialog;
+	GtkFileFilter *filter;
+	GtkWidget *preview;
+	int res;
+
+	dialog = gtk_file_chooser_dialog_new (_("Select an Image File"),
+											NULL,
+					      					GTK_FILE_CHOOSER_ACTION_OPEN, 
+					      					GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+					      					GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
+					      					NULL);
+	gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (dialog),
+	    									PACKAGE_PIXMAPS_DIR);
+	filter = gtk_file_filter_new ();
+	gtk_file_filter_add_pixbuf_formats (filter);
+	gtk_file_chooser_set_filter (GTK_FILE_CHOOSER (dialog), filter);
+
+	preview = gtk_image_new ();
+	gtk_file_chooser_set_preview_widget (GTK_FILE_CHOOSER (dialog),
+	    								    preview);
+	g_signal_connect (dialog, "update-preview",
+			  								G_CALLBACK (cb_preview_update), preview);
+
+	res = gtk_dialog_run (GTK_DIALOG (dialog));
+
+	if (res == GTK_RESPONSE_ACCEPT) {
+    	gchar *filename;
+
+    	filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
+		if (filename != NULL)
+		{
+			GtkWidget* image;
+			image = gtk_image_new_from_file (filename);
+			gtk_button_set_image (button, image);
+			gtk_button_set_label (button, NULL);
+		}
+		else
+		{
+			gtk_button_set_image (button, NULL);
+			gtk_button_set_label (button, _("Choose Icon"));
+		}
+		atp_user_tool_set_icon (this->tool, filename);
+		g_free (filename);
+	}
+
+	gtk_widget_destroy (dialog);
+}
+
 static void
 atp_clear_tool_editor(ATPToolEditor* this)
 {
@@ -603,19 +690,30 @@ atp_populate_tool_editor(ATPToolEditor* this)
 	}
 	atp_editor_update_shortcut (this);
 
-	gnome_icon_entry_set_filename (this->icon_en, atp_user_tool_get_icon (this->tool));
+	if (atp_user_tool_get_icon (this->tool))
+	{
+		GtkWidget* image;
+		image = gtk_image_new_from_file (atp_user_tool_get_icon (this->tool));
+		gtk_button_set_image (this->icon_en, image);
+		gtk_button_set_label (this->icon_en, NULL);
+	}
+	else
+	{
+		gtk_button_set_image (this->icon_en, NULL);
+		gtk_button_set_label (this->icon_en, _("Choose Icon"));
+	}
 }
 
-static void
-on_editor_terminal_toggle (GtkToggleButton *tb, gpointer user_data)
+void
+atp_on_editor_terminal_toggle (GtkToggleButton *tb, gpointer user_data)
 {
 	ATPToolEditor *this = (ATPToolEditor *)user_data;
 
 	atp_update_sensitivity (this);
 }
 
-static void
-on_editor_script_toggle (GtkToggleButton *tb, gpointer user_data)
+void
+atp_on_editor_script_toggle (GtkToggleButton *tb, gpointer user_data)
 {
 	ATPToolEditor *this = (ATPToolEditor *)user_data;
 	gchar* command;
@@ -663,22 +761,21 @@ on_editor_script_toggle (GtkToggleButton *tb, gpointer user_data)
 	}
 }
 
-static void
-on_editor_input_changed (GtkComboBox *combo, gpointer user_data)
+void
+atp_on_editor_input_changed (GtkComboBox *combo, gpointer user_data)
 {
 	ATPToolEditor *this = (ATPToolEditor *)user_data;
 
 	atp_update_sensitivity (this);
 }
 
-static void
-on_editor_response (GtkDialog *dialog, gint response, gpointer user_data)
+void
+atp_on_editor_dialog_response (GtkDialog *dialog, gint response, gpointer user_data)
 {
 	ATPToolEditor* this = (ATPToolEditor*)user_data;
 	gchar* name;
 	gchar* data;
 	ATPInputType in_type;
-	gchar* value;
 	guint accel_key;
 	GdkModifierType accel_mods;
 	GtkAccelGroup* group;
@@ -768,10 +865,6 @@ on_editor_response (GtkDialog *dialog, gint response, gpointer user_data)
 
 		atp_user_tool_set_accelerator (this->tool, accel_key, accel_mods);
 
-		value = gnome_icon_entry_get_filename (this->icon_en);	
-		atp_user_tool_set_icon (this->tool, value);
-		g_free (value);	
-
 		/* Open script in editor if requested */
 		if (gtk_toggle_button_get_active (this->script_tb))
 		{
@@ -843,24 +936,24 @@ on_editor_response (GtkDialog *dialog, gint response, gpointer user_data)
 	atp_tool_editor_free (this);
 }
 
-static void
-on_editor_param_variable_show (GtkButton *button, gpointer user_data)
+void
+atp_on_editor_param_variable_show (GtkButton *button, gpointer user_data)
 {
 	ATPToolEditor* this = (ATPToolEditor*)user_data;
 
 	atp_variable_dialog_show (&this->param_var, ATP_DEFAULT_VARIABLE);	
 }
 
-static void
-on_editor_dir_variable_show (GtkButton *button, gpointer user_data)
+void
+atp_on_editor_dir_variable_show (GtkButton *button, gpointer user_data)
 {
 	ATPToolEditor* this = (ATPToolEditor*)user_data;
 
 	atp_variable_dialog_show (&this->dir_var, ATP_DIRECTORY_VARIABLE);
 }
 
-static void
-on_editor_input_variable_show (GtkButton *button, gpointer user_data)
+void
+atp_on_editor_input_variable_show (GtkButton *button, gpointer user_data)
 {
 	ATPToolEditor* this = (ATPToolEditor*)user_data;
 
@@ -938,8 +1031,8 @@ on_editor_get_keys(GtkWidget *widget, GdkEventKey *event, gpointer user_data)
 	return TRUE;
 }
 
-static void
-on_editor_shortcut_toggle (GtkToggleButton *tb, gpointer user_data)
+void
+atp_on_editor_shortcut_toggle (GtkToggleButton *tb, gpointer user_data)
 {
 	ATPToolEditor *this = (ATPToolEditor *)user_data;
 
@@ -959,10 +1052,54 @@ on_editor_shortcut_toggle (GtkToggleButton *tb, gpointer user_data)
 	}
 }
 
+void
+atp_on_editor_browse_button_clicked (GtkButton *button, GtkEntry *entry)
+{
+	GtkWidget *dialog;
+	dialog = gtk_file_chooser_dialog_new ("Open File",
+					      NULL,
+					      GTK_FILE_CHOOSER_ACTION_OPEN,
+					      GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+					      GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
+					      NULL);
+	if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT)
+	{
+		char *filename;
+		filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
+
+		gtk_entry_set_text (entry, filename);
+
+		g_free (filename);
+	}
+	gtk_widget_destroy(dialog);
+}
+
+void
+atp_on_editor_browse_button_dir_clicked (GtkButton *button, GtkEntry *entry)
+{
+	GtkWidget *dialog;
+	dialog = gtk_file_chooser_dialog_new ("Open",
+					      NULL,
+					      GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER,
+					      GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+					      GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
+					      NULL);
+	if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT)
+	{
+		char *filename;
+		filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
+
+		gtk_entry_set_text (entry, filename);
+
+		g_free (filename);
+	}
+	gtk_widget_destroy(dialog);
+}
+
 gboolean
 atp_tool_editor_show (ATPToolEditor* this)
 {
-	GladeXML *xml;
+	GtkBuilder *bxml;
 
 	if (this->dialog != NULL)
 	{
@@ -971,36 +1108,37 @@ atp_tool_editor_show (ATPToolEditor* this)
 		return TRUE;
 	}
 
-	if (NULL == (xml = glade_xml_new(GLADE_FILE, TOOL_EDITOR, NULL)))
-	{
-		anjuta_util_dialog_error (atp_tool_dialog_get_window (this->parent), _("Unable to build user interface for tool editor"));
-		g_free(this);
+	bxml = anjuta_util_builder_new (GLADE_FILE, NULL);
+	if (!bxml) return FALSE;
 
-		return FALSE;
-	}
-	this->dialog = glade_xml_get_widget(xml, TOOL_EDITOR);
+	/* Get all objects */
+	anjuta_util_builder_get_objects (bxml,
+	    TOOL_EDITOR, &this->dialog,
+		TOOL_NAME, &this->name_en ,
+		TOOL_COMMAND, &this->command_en,
+		TOOL_PARAM, &this->param_en,
+		TOOL_WORKING_DIR, &this->dir_en,
+		TOOL_ENABLED, &this->enabled_tb,
+		TOOL_TERMINAL, &this->terminal_tb,
+		TOOL_AUTOSAVE, &this->autosave_tb,
+		TOOL_SCRIPT, &this->script_tb,
+		TOOL_OUTPUT, &this->output_com,
+		TOOL_ERROR, &this->error_com,
+		TOOL_INPUT, &this->input_com,
+		TOOL_INPUT_VALUE, &this->input_en,
+		TOOL_INPUT_VARIABLE, &this->input_var_bt,
+		TOOL_SHORTCUT, &this->shortcut_bt,
+		TOOL_ICON, &this->icon_en,
+	    NULL);
+	    
 	gtk_widget_show (this->dialog);
 	gtk_window_set_transient_for (GTK_WINDOW (this->dialog), atp_plugin_get_app_window (this->parent->plugin));
 
-	this->name_en = GTK_EDITABLE (glade_xml_get_widget (xml, TOOL_NAME));
-	this->command_en = GTK_EDITABLE (glade_xml_get_widget (xml, TOOL_COMMAND));
-	this->param_en = GTK_EDITABLE (glade_xml_get_widget (xml, TOOL_PARAM));
+	/* Initialize entries */
 	atp_variable_dialog_set_entry (&this->param_var, this->param_en);
-	this->dir_en = GTK_EDITABLE (glade_xml_get_widget (xml, TOOL_WORKING_DIR));
 	atp_variable_dialog_set_entry (&this->dir_var, this->dir_en);
-	this->enabled_tb = GTK_TOGGLE_BUTTON (glade_xml_get_widget (xml, TOOL_ENABLED));
-	this->terminal_tb = GTK_TOGGLE_BUTTON (glade_xml_get_widget(xml, TOOL_TERMINAL));
-	this->autosave_tb = GTK_TOGGLE_BUTTON (glade_xml_get_widget(xml, TOOL_AUTOSAVE));
-	this->script_tb = GTK_TOGGLE_BUTTON (glade_xml_get_widget(xml, TOOL_SCRIPT));
-	this->output_com = GTK_COMBO_BOX (glade_xml_get_widget(xml, TOOL_OUTPUT));
-	this->error_com = GTK_COMBO_BOX (glade_xml_get_widget(xml, TOOL_ERROR));
-	this->input_com = GTK_COMBO_BOX (glade_xml_get_widget(xml, TOOL_INPUT));
-	this->input_en = GTK_EDITABLE (glade_xml_get_widget(xml, TOOL_INPUT_VALUE));
-	this->input_var_bt = GTK_BUTTON (glade_xml_get_widget(xml, TOOL_INPUT_VARIABLE));
-	this->shortcut_bt = GTK_TOGGLE_BUTTON (glade_xml_get_widget(xml, TOOL_SHORTCUT));
 	atp_variable_dialog_set_entry (&this->input_file_var, this->input_en);
 	atp_variable_dialog_set_entry (&this->input_string_var, this->input_en);
-	this->icon_en = GNOME_ICON_ENTRY (glade_xml_get_widget(xml, TOOL_ICON));
 
 	/* Add combox box value */
 	set_combo_box_enum_model (this->error_com, atp_get_error_type_list());
@@ -1011,17 +1149,10 @@ atp_tool_editor_show (ATPToolEditor* this)
 	atp_populate_tool_editor (this);
 	atp_update_sensitivity (this);
 
-	/* Connect all signals */	
-	glade_xml_signal_connect_data (xml, EDITOR_RESPONSE_SIGNAL, GTK_SIGNAL_FUNC (on_editor_response), this);
-	glade_xml_signal_connect_data (xml, EDITOR_PARAM_VARIABLE_SIGNAL, GTK_SIGNAL_FUNC (on_editor_param_variable_show), this);
-	glade_xml_signal_connect_data (xml, EDITOR_DIR_VARIABLE_SIGNAL, GTK_SIGNAL_FUNC (on_editor_dir_variable_show), this);
-	glade_xml_signal_connect_data (xml, EDITOR_TOGGLE_SHORCUT_SIGNAL, GTK_SIGNAL_FUNC (on_editor_shortcut_toggle), this);
-	glade_xml_signal_connect_data (xml, EDITOR_TOGGLE_TERMINAL_SIGNAL, GTK_SIGNAL_FUNC (on_editor_terminal_toggle), this);
-	glade_xml_signal_connect_data (xml, EDITOR_TOGGLE_SCRIPT_SIGNAL, GTK_SIGNAL_FUNC (on_editor_script_toggle), this);
-	glade_xml_signal_connect_data (xml, EDITOR_INPUT_VARIABLE_SIGNAL, GTK_SIGNAL_FUNC (on_editor_input_variable_show), this);
-	glade_xml_signal_connect_data (xml, EDITOR_INPUT_CHANGED_SIGNAL, GTK_SIGNAL_FUNC (on_editor_input_changed), this);
-
-	g_object_unref (xml);
+	/* Connect all signals */
+	gtk_builder_connect_signals (bxml, this);
+	
+	g_object_unref (bxml);
 
 	return TRUE;
 }
